From 2d05ce37c60a157760f386badc387e2d53b2fa75 Mon Sep 17 00:00:00 2001
From: Benno Schulenberg <bensberg@telfort.nl>
Date: Thu, 5 Mar 2020 16:57:16 +0100
Subject: [PATCH] justify: do not crash when the user attempts to justify an
 empty region

This fixes https://savannah.gnu.org/bugs/?57959.

Bug existed since version 4.0, since the justifying
of a marked region was introduced.
---
 src/text.c | 6 ++++++
 1 file changed, 6 insertions(+)

diff --git a/src/text.c b/src/text.c
index 957938f4..4fe7eb96 100644
--- a/src/text.c
+++ b/src/text.c
@@ -1930,6 +1930,12 @@ void do_justify(bool full_justify)
 		get_region((const linestruct **)&first_par_line, &top_x,
 					(const linestruct **)&last_par_line, &bot_x, &right_side_up);
 
+		/* When the marked region is empty, do nothing. */
+		if (first_par_line == last_par_line && top_x == bot_x) {
+			statusline(NOTICE, _("Nothing changed"));
+			return;
+		}
+
 		/* Save the starting point of the marked region. */
 		was_top_lineno = first_par_line->lineno;
 		was_top_x = top_x;
-- 
2.25.2

